@@ -5,7 +5,7 @@
 ;; Author: Michael Albinus <michael.albinus@gmx.de>
 ;; Keywords: comm, hypermedia
 ;; Package: debbugs
-;; Version: 0.40
+;; Version: 0.41
 ;; Package-Requires: ((emacs "26.1") (soap-client "3.1.5"))
 
 ;; This file is not part of GNU Emacs.
@@ -38,13 +38,14 @@
 
 ;;; Code:
 
+(require 'debbugs-compat)
 (require 'subr-x)
 ;(setq soap-debug t url-debug t message-log-max t)
 (require 'soap-client)
 (eval-when-compile (require 'cl-lib))
 
 (defgroup debbugs nil
-  "Debbugs library"
+  "Debbugs library."
   :group 'hypermedia)
 
 (defcustom debbugs-servers
@@ -56,10 +57,10 @@
      :bugreport-url "https://bugs.debian.org/cgi-bin/bugreport.cgi"))
   "*List of Debbugs server specifiers.
 Each entry is a list that contains a string identifying the port
-name and the server parameters in keyword-value form. Allowed
+name and the server parameters in keyword-value form.  Allowed
 keywords are:
 
-`:wsdl' -- Location of WSDL. The value is a string with URL that
+`:wsdl' -- Location of WSDL.  The value is a string with URL that
 should return the WSDL specification of Debbugs/SOAP service.
 
 `:bugreport-url' -- URL of the server script that returns mboxes
@@ -82,7 +83,7 @@ servers: \"gnu.org\" and \"debian.org\"."
 				   (string :tag "Bugreport URL")))))))
 
 (defcustom debbugs-port "gnu.org"
-  "The port instance to be applied from `debbugs-wsdl'.
+  "The port instance to be applied from `debbugs-servers'.
 This corresponds to the Debbugs server to be accessed, either
 \"gnu.org\", or \"debian.org\", or user defined port name."
   ;; Maybe we should create an own group?
@@ -113,20 +114,31 @@ This corresponds to the Debbugs server to be accessed, either
 (defcustom debbugs-cache-expiry (* 60 60)
   "How many seconds debbugs query results are cached.
 t or 0 disables caching, nil disables expiring."
-  :type '(choice (const :tag "Always" t)
-		 (const :tag "Never" nil)
+  :type '(choice (const :tag "Never" t)
+		 (const :tag "Forever" nil)
 		 (integer :tag "Seconds")))
 
+(defun debbugs-soap-invoke (operation-name &rest parameters)
+  "Invoke the SOAP connection.
+OPERATION-NAME and PARAMETERS are as described in `soap-invoke'."
+  (debbugs-compat-add-debbugs-advice)
+  (prog1
+      (apply #'soap-invoke operation-name parameters)
+    (debbugs-compat-remove-debbugs-advice)))
+
 (defvar debbugs-soap-invoke-async-object nil
   "The object manipulated by `debbugs-soap-invoke-async'.")
 
 (defun debbugs-soap-invoke-async (operation-name &rest parameters)
-  "Invoke the SOAP connection asynchronously."
+  "Invoke the SOAP connection asynchronously.
+OPERATION-NAME and PARAMETERS are as described in `soap-invoke'."
+  (debbugs-compat-add-debbugs-advice)
   (apply
    #'soap-invoke-async
    (lambda (response &rest _args)
      (setq debbugs-soap-invoke-async-object
-	   (append debbugs-soap-invoke-async-object (car response))))
+	   (append debbugs-soap-invoke-async-object (car response)))
+     (debbugs-compat-remove-debbugs-advice))
    nil debbugs-wsdl debbugs-port operation-name parameters))
 
 (defcustom debbugs-show-progress t
@@ -233,7 +245,7 @@ Valid keywords are:
   :affects -- With this keyword it is possible to find bugs which
   affect the package with the given name.  The bugs are chosen by
   the value of field `affects' in bug's status.  The returned bugs
-  do not necessary belong to this package.
+  usually do not belong to this package.
 
   :status -- Status of bug.  Valid values are \"open\",
   \"forwarded\" and \"done\".
@@ -259,7 +271,8 @@ patch:
 	debbugs-progress-reporter-buffers url-show-status vec kw key val)
     (when debbugs-show-progress
       (add-function
-       :override (symbol-function debbugs-url-display-message-or-percentage-function)
+       :override
+       (symbol-function debbugs-url-display-message-or-percentage-function)
        #'debbugs-url-display-message-or-percentage
        '((name . "debbugs-url-display-message-or-percentage"))))
 
@@ -301,7 +314,8 @@ patch:
     (unless (null query)
       (error "Unknown key: %s" (car query)))
     (prog1
-	(sort (car (soap-invoke debbugs-wsdl debbugs-port "get_bugs" vec)) #'<)
+	(sort (car (debbugs-soap-invoke
+                    debbugs-wsdl debbugs-port "get_bugs" vec)) #'<)
       (when debbugs-show-progress
 	(remove-function
 	 (symbol-function debbugs-url-display-message-or-percentage-function)
@@ -337,7 +351,7 @@ patch:
 	    (cons 'cache_time (float-time))
 	    (cons 'newest_bug
 		  (caar
-		   (soap-invoke
+		   (debbugs-soap-invoke
 		    debbugs-wsdl debbugs-port "newest_bugs" amount)))))
 
 	  ;; Cache it.
@@ -348,7 +362,8 @@ patch:
 	(list (alist-get 'newest_bug status)))
 
     (sort
-     (car (soap-invoke debbugs-wsdl debbugs-port "newest_bugs" amount)) #'<)))
+     (car (debbugs-soap-invoke
+           debbugs-wsdl debbugs-port "newest_bugs" amount)) #'<)))
 
 (defun debbugs-convert-soap-value-to-string (string-value)
   "If STRING-VALUE is unibyte, decode its contents as a UTF-8 string.
@@ -380,7 +395,7 @@ Every returned entry is an association list with the following attributes:
 
   `package': A list of package names the bug belongs to.
 
-  `severity': The severity of the bug report. This can be
+  `severity': The severity of the bug report.  This can be
   \"critical\", \"grave\", \"serious\", \"important\",
   \"normal\", \"minor\" or \"wishlist\".
 
@@ -458,8 +473,7 @@ Example:
     ;; Check for cached bugs.
     (setq bug-numbers (delete-dups bug-numbers)
 	  bug-numbers
-	  (delete
-	   nil
+	  (delq nil
 	   (mapcar
 	    (lambda (bug)
 	      (let ((status (gethash bug debbugs-cache-data)))
@@ -488,7 +502,8 @@ Example:
 	    debbugs-progress-reporter-buffers url-show-status results res)
 	(when debbugs-show-progress
 	  (add-function
-	   :override (symbol-function debbugs-url-display-message-or-percentage-function)
+	   :override
+           (symbol-function debbugs-url-display-message-or-percentage-function)
 	   #'debbugs-url-display-message-or-percentage
 	   '((name . "debbugs-url-display-message-or-percentage"))))
 
@@ -641,7 +656,8 @@ Example:
 
     (setq
      object
-     (car (soap-invoke debbugs-wsdl debbugs-port "get_usertag" (car user))))
+     (car (debbugs-soap-invoke
+           debbugs-wsdl debbugs-port "get_usertag" (car user))))
 
     (if (null tags)
 	;; Return the list of existing tags.
@@ -668,7 +684,7 @@ Every message is an association list with the following attributes:
 
   `attachments' A list of possible attachments, or nil.  Not
   implemented yet server side."
-  (car (soap-invoke debbugs-wsdl debbugs-port "get_bug_log" bug-number)))
+  (car (debbugs-soap-invoke debbugs-wsdl debbugs-port "get_bug_log" bug-number)))
 
 (defun debbugs-search-est (&rest query)
   "Return the result of a full text search according to QUERY.
@@ -679,7 +695,7 @@ VALUE]*
 
 Every sublist of the QUERY forms a hyperestraier condition.  A
 detailed description of hyperestraier conditions can be found at
-URL `https://fallabs.com/hyperestraier/uguide-en.html#searchcond'.
+URL `https://dbmx.net/hyperestraier/uguide-en.html#searchcond'.
 
 The following conditions are possible:
 
@@ -805,7 +821,8 @@ Examples:
     (when debbugs-create-progress-reporter
       (setq debbugs-progress-reporter (make-progress-reporter "Query bugs..."))
       (add-function
-       :override (symbol-function debbugs-url-display-message-or-percentage-function)
+       :override
+       (symbol-function debbugs-url-display-message-or-percentage-function)
        #'debbugs-url-display-message-or-percentage
        '((name . "debbugs-url-display-message-or-percentage"))))
 
@@ -952,7 +969,8 @@ Examples:
 	  (setq args (vconcat args (list vec)))))
 
       (setq result
-	    (car (soap-invoke debbugs-wsdl debbugs-port "search_est" args)))
+	    (car (debbugs-soap-invoke
+                  debbugs-wsdl debbugs-port "search_est" args)))
       ;; The result contains lists (key value).  We transform it into
       ;; cons cells (key . value).
       (dolist (elt1 result)
@@ -976,7 +994,8 @@ BUG-OR-MESSAGE must be list element returned by either
 Example: Return the originator of last submitted bug.
 
 \(debbugs-get-attribute
-  \(car \(apply #\\='debbugs-get-status \(debbugs-newest-bugs 1))) \\='originator)"
+  \(car \(apply #\\='debbugs-get-status \(debbugs-newest-bugs 1)))
+  \\='originator)"
   (alist-get attribute bug-or-message))
 
 (defun debbugs-get-message-numbers (messages)
